@@ -465,7 +465,7 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                         
                         print("Number of Samples Gathered:", len(trainingSignature))
                         print("Size of file:", sys.getsizeof(trainingSignature))
-                        np.savetxt(outputPath+'/'+phylumOfChoice+'_'+organism+'.csv',trainingSignature,delimiter=",")
+                        np.savetxt(outputPath+'/'+phylumOfChoice+'_'+organism.replace("/","-")+'.csv',trainingSignature,delimiter=",")
 
         
         else:
@@ -522,8 +522,6 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
                                 
                                 print("Number of Samples Gathered:", len(trainingSignature))
                                 print("Size of file:", sys.getsizeof(trainingSignature))
-                                print(organism)
-                                print(organism.replace("/","-"))
                                 np.savetxt(outputPath+'/'+phylum+'_'+organism.replace("/","-")+'.csv',trainingSignature,delimiter=",")
 
         return None
